"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.MergeEditorFloatComponents = void 0;
const tslib_1 = require("tslib");
const react_1 = tslib_1.__importStar(require("react"));
const ide_core_browser_1 = require("@opensumi/ide-core-browser");
const ide_core_common_1 = require("@opensumi/ide-core-common");
const git_1 = require("@opensumi/ide-core-common/lib/commands/git");
const merge_actions_1 = require("@opensumi/ide-monaco/lib/browser/contrib/merge-editor/components/merge-actions");
const useEditor_1 = require("../hooks/useEditor");
const merge_conflict_1 = require("../merge-conflict");
const MergeEditorFloatComponents = ({ resource }) => {
    const { uri } = resource;
    const editorModel = (0, useEditor_1.useEditorDocumentModelRef)(uri);
    const mergeConflictParser = (0, ide_core_browser_1.useInjectable)(merge_conflict_1.MergeConflictParser);
    const commandService = (0, ide_core_browser_1.useInjectable)(ide_core_browser_1.CommandService);
    const commandRegistry = (0, ide_core_browser_1.useInjectable)(ide_core_browser_1.CommandRegistry);
    const [isVisiable, setIsVisiable] = (0, react_1.useState)(false);
    const [conflicts, setConflicts] = (0, react_1.useState)([]);
    (0, react_1.useEffect)(() => {
        const disposables = new ide_core_browser_1.DisposableStore();
        if (editorModel) {
            const { instance } = editorModel;
            const run = () => {
                const conflicts = mergeConflictParser.scanDocument(instance.getMonacoModel());
                if (conflicts.length > 0) {
                    setIsVisiable(true);
                    setConflicts(conflicts);
                }
                else {
                    setIsVisiable(false);
                    setConflicts([]);
                }
            };
            disposables.add(editorModel.instance.getMonacoModel().onDidChangeContent(() => {
                run();
            }));
            run();
            return () => {
                disposables.dispose();
            };
        }
    }, [editorModel]);
    const [isAIResolving, setIsAIResolving] = (0, react_1.useState)(false);
    const handlePrev = (0, react_1.useCallback)(() => {
        commandService.tryExecuteCommand(git_1.MergeConflictCommands.Previous).then(() => {
            // TODO: 编辑器向上滚动一行
        });
    }, []);
    const handleNext = (0, react_1.useCallback)(() => {
        commandService.tryExecuteCommand(git_1.MergeConflictCommands.Next).then(() => {
            // TODO: 编辑器向上滚动一行
        });
    }, []);
    const handleAIResolve = (0, react_1.useCallback)(async () => {
        setIsAIResolving(true);
        if (isAIResolving) {
            await commandService.executeCommand(ide_core_browser_1.MERGE_CONFLICT_COMMANDS.AI_ALL_ACCEPT_STOP.id, uri);
        }
        else {
            await commandService.executeCommand(ide_core_browser_1.MERGE_CONFLICT_COMMANDS.AI_ALL_ACCEPT.id, uri);
        }
        setIsAIResolving(false);
    }, [uri, isAIResolving]);
    if (!isVisiable) {
        return null;
    }
    const summary = (0, ide_core_common_1.formatLocalize)('merge-conflicts.merge.conflict.remain', conflicts.length);
    return (react_1.default.createElement(merge_actions_1.MergeActions, { uri: uri, editorType: 'text', summary: summary, handleNext: handleNext, handlePrev: handlePrev, isAIResolving: isAIResolving, onAIResolve: handleAIResolve, onReset: () => {
            commandService.executeCommand(ide_core_browser_1.MERGE_CONFLICT_COMMANDS.ALL_RESET.id, uri);
        }, onSwitchEditor: () => {
            [ide_core_browser_1.SCM_COMMANDS.GIT_OPEN_MERGE_EDITOR, ide_core_browser_1.SCM_COMMANDS._GIT_OPEN_MERGE_EDITOR].forEach(({ id: command }) => {
                if (commandRegistry.getCommand(command) && commandRegistry.isEnabled(command)) {
                    commandService.executeCommand(command, uri);
                }
            });
        } }));
};
exports.MergeEditorFloatComponents = MergeEditorFloatComponents;
//# sourceMappingURL=MergeEditorFloatComponents.js.map